@@ -12,9 +12,11 @@
 #include <string.h>
 #include <getopt.h>
 #include <ctype.h>
-#include <unistd.h> /* for access() */
 #include <libintl.h>
 #include <locale.h>
+#include <sys/types.h> /* for getpwnam() */
+#include <pwd.h>       /* for getpwnam() */
+#include <unistd.h>    /* for access() */
 
 #include <X11/Xlib.h>
 
@@ -31,7 +33,7 @@
 #include <gpe/stylus.h>
 #include <gpe/translabel.h>
 
-#include <rootpixmap.h>
+#include "gpe-ownerinfo.h"
 
 #define CURRENT_DATAFILE_VER 2
 
@@ -44,22 +46,20 @@
 
 #define _(_x) gettext(_x)
 
-GtkWidget *GPE_Ownerinfo;
-GtkWidget *name;
-GtkWidget *phone;
-GtkWidget *email;
-GtkWidget *address;
-GdkPixbuf *photopixbuf;
-GtkWidget *smallphotobutton;
-GtkWidget *bigphotobutton;
-gchar *photofile = PREFIX "/share/gpe/pixmaps/default/tux-48.png";
-PangoLayout *address_layout;
-guint lost_height;
-GtkWidget *scrollbar;
-gchar *pango_lang_code;
+static GtkWidget *name;
+static GtkWidget *phone;
+static GtkWidget *email;
+static GtkWidget *address;
+static GdkPixbuf *photopixbuf;
+static GtkWidget *smallphotobutton;
+static GtkWidget *bigphotobutton;
+static gchar *photofile = PREFIX "/share/gpe/pixmaps/default/tux-48.png";
+static PangoLayout *address_layout;
+static guint lost_height;
+static GtkWidget *scrollbar;
 
 /* redraw the pixbuf */
-gboolean
+static gboolean
 on_expose_event (GtkWidget *widget, GdkEventExpose *event, gpointer data)
 {
   gint width  = 10;
@@ -90,7 +90,8 @@ on_expose_event (GtkWidget *widget, GdkEventExpose *event, gpointer data)
   resultwidth  = (gint) (width  * scale);
   resultheight = (gint) (height * scale);
 
-  scaledpixbuf = gdk_pixbuf_scale_simple (photopixbuf, resultwidth, resultheight, GDK_INTERP_BILINEAR);
+  scaledpixbuf = gdk_pixbuf_scale_simple (photopixbuf, resultwidth, resultheight,
+					  GDK_INTERP_BILINEAR);
 
   gdk_pixbuf_render_to_drawable_alpha (scaledpixbuf, widget->window,
 				       0, 0,                      /* src_x, src_y */
@@ -105,42 +106,34 @@ on_expose_event (GtkWidget *widget, GdkEventExpose *event, gpointer data)
   return TRUE;
 }
 
-void
+static void
 on_smallphotobutton_clicked            (GtkButton       *button,
                                         GtkWidget       *notebook)
 {
   gtk_notebook_set_page (GTK_NOTEBOOK (notebook), 1);
 }
 
-void
+static void
 on_bigphotobutton_clicked              (GtkButton       *button,
                                         GtkWidget       *notebook)
 {
   gtk_notebook_set_page (GTK_NOTEBOOK (notebook), 0);
 }
 
-void
-realize (GtkWidget *w)
-{
-  GtkViewport *vp = GTK_VIEWPORT (w);
-
-  gdk_window_set_back_pixmap (vp->view_window, NULL, TRUE);
-  gdk_window_set_back_pixmap (vp->bin_window, NULL, TRUE);
-}
-
 /*
  *  Return value: upgrade status
  *
  *  The data file format is described in the file HACKING.
  */
 
-gint
+static gint
 upgrade_to_v2 (guint new_version)
 {
   gchar *firstline, *oldcontent;
   FILE *fp;
   
-  firstline = g_strdup ("Initial firstline, must be looooooooooooooooooong enough for the later content");
+  firstline = g_strdup ("Initial firstline, must be looooooooooooooooooong"
+			" enough for the later content");
   sprintf (firstline, "%s %d]", INFO_MATCH, new_version);
   oldcontent = g_strdup ("Initial oldcontent.");
   
@@ -191,7 +184,7 @@ upgrade_to_v2 (guint new_version)
 }
 
 
-gint
+static gint
 maybe_upgrade_datafile ()
 {
   gchar *firstline;
@@ -217,12 +210,14 @@ maybe_upgrade_datafile ()
 	    version = strtol (firstline + strlen (INFO_MATCH), (char **)NULL, 10);
 	    
 	    if (version == 0) {
-	      fprintf (stderr, "gpe-ownerinfo: file '%s' is version %d, which should not happen.\n",
+	      fprintf (stderr, "gpe-ownerinfo: file '%s' is version %d,"
+		       " which should not happen.\n",
 		       GPE_OWNERINFO_DATA, version);
 	      fprintf (stderr, "   Please file a bug. I am continuing anyway.\n");
 	    }
 	    if (version > CURRENT_DATAFILE_VER) {
-	      fprintf (stderr, "gpe-ownerinfo: file '%s' is version %d.\n   I only know how to handle version %d. Exiting.\n",
+	      fprintf (stderr, "gpe-ownerinfo: file '%s' is version %d.\n"
+		       "   I only know how to handle version %d. Exiting.\n",
 		       GPE_OWNERINFO_DATA, version, CURRENT_DATAFILE_VER);
 	      fclose (fp);
 	      exit (1);
@@ -259,7 +254,8 @@ maybe_upgrade_datafile ()
     }
 
   if (upgrade_result == UPGRADE_ERROR) {
-    printf ("gpe-ownerinfo: Had found version %d, but cannot upgrade for some reason.\n", version);
+    printf ("gpe-ownerinfo: Had found version %d,"
+	    " but cannot upgrade for some reason.\n", version);
     return (UPGRADE_ERROR);
   }
   else {
@@ -269,25 +265,6 @@ maybe_upgrade_datafile ()
 }
 
 
-static void
-mapped (GtkWidget *window)
-{
-  Pixmap rmap = GetRootPixmap (GDK_DISPLAY ());
-  if (rmap != None)
-    {
-      Pixmap pmap;
-      pmap = CutWinPixmap (GDK_DISPLAY(), GDK_WINDOW_XWINDOW (window->window), rmap, 
-			   GDK_GC_XGC (window->style->black_gc));
-      if (pmap != None)
-	{
-	  GtkStyle *style = gtk_style_copy (window->style);
-	  GdkPixmap *gpmap = gdk_pixmap_foreign_new (pmap);      
-	  style->bg_pixmap[GTK_STATE_NORMAL] = gpmap;
-	  gtk_widget_set_style (window, style);
-	}
-    }
-}
-
 static gboolean
 draw_address (GtkWidget *widget, GdkEventExpose *event, gpointer user_data)
 {
@@ -337,28 +314,27 @@ set_address_size (GtkWidget *widget, GtkAllocation *allocation, gpointer user_da
   adj->page_size = (double)allocation->height / (double)height;
 }
 
-void
+static void
 translate_name_label (GtkWidget *namelabel, gpointer data)
 {
   gtk_label_set_markup (GTK_LABEL (namelabel),
-			g_strdup_printf ("<span lang='%s'><b>%s</b></span> ",
-					 pango_lang_code, _("Owner")));
+			/* cheat a bit with the space here*/
+			g_strdup_printf ("<b>%s</b> ",
+					 /* TRANSLATORS: only a short word will look good
+					  here.  If the word is shorter than 5 letters,
+					  please fill it up with spaces.*/
+					 _("Owner")));
 }
 
-int
-main (int argc, char *argv[])
+GtkWidget *
+gpe_owner_info (void)
 {
-  gchar *package_revision = "$Revision: 1.29 $";
-  
-  GtkWidget *GPE_Ownerinfo;
   GtkWidget *notebook;
   GtkWidget *mainvbox;
-  GtkWidget *catlabel;
   GtkWidget *cathbox;
   GtkWidget *indentedhbox;
   GtkWidget *leftcolvbox;
   GtkWidget *namelabel;
-  GtkWidget *addresslabel;
   GtkWidget *address_button_vbox;
   GtkWidget *smallphotodrawingarea;
   GtkWidget *bigphotodrawingarea;
@@ -366,6 +342,7 @@ main (int argc, char *argv[])
   GtkWidget *addresshbox;
   GtkSizeGroup *sizegroup;
   GtkObject *adjustment;
+  gint upgrade_result = UPGRADE_ERROR;
   
   /* gchar *gpe_catindent = gpe_get_catindent ();  */
   /* guint gpe_catspacing = gpe_get_catspacing (); */
@@ -375,70 +352,17 @@ main (int argc, char *argv[])
   gchar *ownername, *owneremail, *ownerphone, *owneraddress;
   gchar *ownerphotofile;
   FILE *fp;
-  gchar * geometry = NULL;
-  gboolean flag_transparent = FALSE;
-  gboolean flag_keep_on_top = FALSE;
-  gint x = -1, y = -1, h = 0, w = 0;
-  gint val;
-  gint opt;
-  gint upgrade_result = UPGRADE_ERROR;
 
-  /* TRANSLATORS: please replace this with the Pango code for your own language */
-  pango_lang_code = g_strdup (_("en"));
-  
-  setlocale (LC_ALL, "");
-
-  bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
-  textdomain (PACKAGE);
-  bind_textdomain_codeset (PACKAGE, "UTF-8");
-
-  while ((opt = getopt (argc,argv,"hktg:")) != EOF)
-    {
-      switch (opt) {
-      case 'g':
-	geometry = optarg;
-	break;
-      case 't':
-	flag_transparent = TRUE;
-	break;
-      case 'k':
-	flag_keep_on_top = TRUE;
-	break;
-      case 'h':
-	printf (g_strdup_printf ("%s %s", _("GPE Owner Info"), package_revision));
-	printf ("\n");
-	printf (_("Valid options:\n"));
-	printf (_("   -g GEOMETRY  window geometry (default: 240x100+0+220)\n"));
-	printf (_("   -t           make window transparent\n"));
-	printf (_("   -k           always keep window on top (override redirect)\n"));
-	printf (_("   -h           this help text\n"));
-	exit (1);
-      case '?':
-	if (isprint (optopt))
-	  ;
-	/* fprintf (stderr, "gpe-ownerinfo: Unknown option -%c'.\n", optopt); */
-	else
-	  fprintf (stderr,
-		   "gpe-ownerinfo: Unknown option character \\x%x'.\n",
-		   optopt);
-	break;
-      default:
-	fprintf (stderr,
-		 "gpe-ownerinfo: Unknown error while parsing command line. Command was %c\n",
-		 opt);
-	exit (1);
-      }
-    }
-    
   ownername    = g_strdup (_("GPE User"));
+  /* TRANSLATORS: you should make sure to not use a 'fantasy' domain
+     which might actually exist (maybe in the future). You can
+     replace the 'nobody' though, or use '@example.org' (see RFC 2606) */
   owneremail   = g_strdup (_("nobody@localhost.localdomain"));
   ownerphone   = g_strdup (_("+99 (9999) 999-9999"));
-  owneraddress = g_strdup_printf ("%s\n"
-				  "<span font_desc='Italic'>%s</span>\n"
-				  "%s" "<span font_desc='Italic'>%s</span>",
-				  _("Configurable with"),
-				  _("Owner Information"),
-				  _("under"), _(" Settings."));
+  /* TRANSLATORS: the translations below should match 'Owner
+     Information' (in gpe-conf) and 'Settings' (in mbdesktop) */
+  owneraddress = g_strdup (_("Configurable with <i>Owner Information</i>"
+			     " under <i>Settings</i>."));
 
   fp = fopen (GPE_OWNERINFO_DATA, "r");
   if (fp)
@@ -452,8 +376,8 @@ main (int argc, char *argv[])
       /* printf ("gpe-ownerinfo: upgrade_result: %d\n", upgrade_result); */
       
       if (upgrade_result == UPGRADE_NOT_NEEDED) {	
-	/*  we have at least version 2, so we need to skip the 1st line
-	 *  and read the photo file name:
+	/*  we have at least datafile version 2, so we need to skip
+	 *  the 1st line and read the photo file name:
 	 */
 	if (fgets (buf, sizeof (buf), fp))
 	  {
@@ -467,7 +391,8 @@ main (int argc, char *argv[])
 	    if (access (ownerphotofile, R_OK) == 0)
 	      photofile = g_strdup (ownerphotofile);
 	    else
-	      fprintf (stderr, "gpe-ownerinfo: file '%s' could not be found,\n   using default file '%s'.\n",
+	      fprintf (stderr, "gpe-ownerinfo: file '%s' could not be found,\n"
+		       "   using default file '%s'.\n",
 		       ownerphotofile, photofile);
 	  }
       }
@@ -510,19 +435,9 @@ main (int argc, char *argv[])
       */
     }
 
-  if (gpe_application_init (&argc, &argv) == FALSE)
-    exit (1);
-
   /* FIXME: check error */
   photopixbuf = gdk_pixbuf_new_from_file (photofile, NULL);
 
-  /* draw the GUI */
-  GPE_Ownerinfo = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  gtk_widget_set_name (GPE_Ownerinfo, "GPE_Ownerinfo");
-  gtk_object_set_data (GTK_OBJECT (GPE_Ownerinfo), "GPE_Ownerinfo", GPE_Ownerinfo);
-  gtk_container_set_border_width (GTK_CONTAINER (GPE_Ownerinfo), 0);
-  gtk_window_set_title (GTK_WINDOW (GPE_Ownerinfo), _("GPE Owner Info"));
-
   /* notebook with two pages;
    * page 1 holds the small photo and the info text,
    * page 2 just the big photo:
@@ -532,7 +447,6 @@ main (int argc, char *argv[])
   GTK_WIDGET_UNSET_FLAGS (notebook, GTK_CAN_FOCUS);
   gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), FALSE);
   gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook), FALSE);
-  gtk_container_add (GTK_CONTAINER (GPE_Ownerinfo), notebook);
 
   /*
    * The first notebook page
@@ -542,12 +456,6 @@ main (int argc, char *argv[])
   gtk_widget_show (mainvbox);
   gtk_container_add (GTK_CONTAINER (notebook), mainvbox);
 
-  catlabel = gtk_label_new (NULL);
-  gtk_label_set_markup (GTK_LABEL (catlabel),
-			g_strdup_printf ("<span lang='%s' weight='bold'>%s</span>",
-					 pango_lang_code, 
-					 _("Owner Information")));
-
   cathbox = gtk_hbox_new (FALSE, 0);
   gtk_widget_show (cathbox);
   gtk_box_pack_start (GTK_BOX (mainvbox), cathbox, TRUE, TRUE, 0);
@@ -559,7 +467,8 @@ main (int argc, char *argv[])
   leftcolvbox = gtk_vbox_new (FALSE, 0);
   gtk_widget_show (leftcolvbox);
   //gtk_box_pack_start (GTK_BOX (indentedhbox), leftcolvbox, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (indentedhbox), leftcolvbox, FALSE, FALSE, gpe_boxspacing);
+  gtk_box_pack_start (GTK_BOX (indentedhbox), leftcolvbox,
+		      FALSE, FALSE, gpe_boxspacing);
 
   namelabel = gtk_label_new (NULL);
   gtk_widget_add_translation_hook (namelabel, translate_name_label, NULL);
@@ -572,11 +481,6 @@ main (int argc, char *argv[])
   gtk_widget_show (address_button_vbox);
   gtk_box_pack_start (GTK_BOX (leftcolvbox), address_button_vbox, TRUE, TRUE, 0);
 
-  addresslabel = gtk_label_new (NULL);
-  gtk_label_set_markup (GTK_LABEL (addresslabel),
-			g_strdup_printf ("<span lang='%s'>%s</span>",
-					 pango_lang_code, _("Address:")));
-
   smallphotobutton = gtk_button_new ();
   gtk_widget_show (smallphotobutton);
   GTK_WIDGET_UNSET_FLAGS (smallphotobutton, GTK_CAN_FOCUS);
@@ -620,10 +524,13 @@ main (int argc, char *argv[])
   address_layout = gtk_widget_create_pango_layout (address, NULL);
   pango_layout_set_markup (address_layout, owneraddress, -1);
 
-  g_signal_connect (G_OBJECT (address), "size-allocate", G_CALLBACK (set_address_size), adjustment);
-  g_signal_connect (G_OBJECT (address), "expose-event", G_CALLBACK (draw_address), adjustment);
+  g_signal_connect (G_OBJECT (address), "size-allocate",
+		    G_CALLBACK (set_address_size), adjustment);
+  g_signal_connect (G_OBJECT (address), "expose-event",
+		    G_CALLBACK (draw_address), adjustment);
 
-  g_signal_connect (G_OBJECT (adjustment), "value-changed", G_CALLBACK (do_scroll_address), address);
+  g_signal_connect (G_OBJECT (adjustment), "value-changed",
+		    G_CALLBACK (do_scroll_address), address);
 
   addresshbox = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (addresshbox), address, TRUE, TRUE, 0);
@@ -652,18 +559,6 @@ main (int argc, char *argv[])
   gtk_widget_show (bigphotodrawingarea);
   gtk_container_add (GTK_CONTAINER (bigphotobutton), bigphotodrawingarea);
   
-  if (flag_transparent)
-    {
-      GtkStyle *style = gtk_style_copy (GPE_Ownerinfo->style);
-      style->bg_pixmap[GTK_STATE_NORMAL] = (GdkPixmap *)GDK_PARENT_RELATIVE;
-      gtk_widget_set_style (smallphotobutton, style);
-      gtk_widget_set_style (smallphotodrawingarea, style);
-      gtk_widget_set_style (address, style);
-      gtk_widget_set_style (scrollbar, style);
-      gtk_widget_set_style (bigphotobutton, style);
-      gtk_widget_set_style (bigphotodrawingarea, style);
-    }
-
   /* Make sure the labels are all the same height (which might not
    * be the case because of the pango markup for e.g. 'email').
    * Don't put 'address' in it, it is too high.
@@ -676,21 +571,6 @@ main (int argc, char *argv[])
 
   /* end of drawing the GUI */
 
-  
-  if (geometry)
-    {
-      val = XParseGeometry (geometry, &x, &y, &w, &h);
-      if ((val & (HeightValue | WidthValue)) == (HeightValue | WidthValue))
-	gtk_widget_set_usize (GPE_Ownerinfo, w, h);
-      if (val & (XValue | YValue))
-	gtk_widget_set_uposition (GPE_Ownerinfo, x, y);
-    }
-  else
-    {
-      gtk_widget_set_usize (GPE_Ownerinfo, 240, 100);
-      gtk_widget_set_uposition (GPE_Ownerinfo, 0, 220); /* 320 - 100 */
-    }
-
   gtk_label_set_markup (GTK_LABEL (name),
 			g_strdup_printf ("<span>%s</span>",
 					 ownername));
@@ -706,15 +586,6 @@ main (int argc, char *argv[])
 					 ownerphone));
   gtk_label_set_selectable (GTK_LABEL (phone), TRUE);
     
-  /* make window transparent if option -t is given: */
-  if (flag_transparent) {
-    gtk_signal_connect (GTK_OBJECT (GPE_Ownerinfo), "map-event",
-			GTK_SIGNAL_FUNC (mapped), NULL);
-  }
-
-  gtk_signal_connect (GTK_OBJECT (GPE_Ownerinfo), "destroy",
-                      GTK_SIGNAL_FUNC (gtk_main_quit),
-                      NULL);
   gtk_signal_connect (GTK_OBJECT (smallphotobutton), "clicked",
 		      GTK_SIGNAL_FUNC (on_smallphotobutton_clicked),
 		      notebook);
@@ -722,14 +593,5 @@ main (int argc, char *argv[])
 		      GTK_SIGNAL_FUNC (on_bigphotobutton_clicked),
 		      notebook);
 
-  gtk_widget_realize (GPE_Ownerinfo);
-
-  if (flag_keep_on_top) {
-    gdk_window_set_override_redirect (GPE_Ownerinfo->window, TRUE);
-  }
-
-  gtk_widget_show (GPE_Ownerinfo);
-
-  gtk_main ();
-  return 0;
+  return notebook;
 }
